AppConfig class

Configuration constants shared between Dart and the native platforms.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

blockScreenshot → const String
Method name to block screenshots.
channel → const String
Method channel name.
unBlockScreenshot → const String
Method name to unblock screenshots.