MethodChannelScreenshotDefender class
An implementation of ScreenshotDefenderPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- ScreenshotDefenderPlatform
- MethodChannelScreenshotDefender
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
block(
) → Future< void> -
Blocks screenshots and screen recordings.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unblock(
) → Future< void> -
Allows screenshots and screen recordings.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited