ScreenshotDefenderPlatform class abstract

The interface that implementations of screenshot_defender must implement.

Platform implementations should extend this class rather than implement it as ScreenshotDefenderPlatform does not consider newly added methods to be breaking changes. Extending this class (using extends) ensures that the subclass will get the default implementation, while platform implementations that implements this interface will be broken by newly added ScreenshotDefenderPlatform methods.

Inheritance
  • Object
  • PlatformInterface
  • ScreenshotDefenderPlatform
Implementers

Constructors

ScreenshotDefenderPlatform()
Constructs a ScreenshotDefenderPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

block() Future<void>
Blocks screenshots and screen recordings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unblock() Future<void>
Allows screenshots and screen recordings.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ScreenshotDefenderPlatform
The default instance of ScreenshotDefenderPlatform to use.
getter/setter pair